@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -50,14 +47,12 @@ class CreateConnectionRequest(proto.Message):
         connection_id (str):
             Optional. Connection id that should be
             assigned to the created connection.
-        connection (~.gcbc_connection.Connection):
+        connection (google.cloud.bigquery_connection_v1.types.Connection):
             Required. Connection to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    connection_id = proto.Field(proto.STRING, number=2)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    connection_id = proto.Field(proto.STRING, number=2,)
     connection = proto.Field(proto.MESSAGE, number=3, message="Connection",)
 
 
@@ -71,7 +66,7 @@ class GetConnectionRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/connections/{connection_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListConnectionsRequest(proto.Message):
@@ -88,11 +83,9 @@ class ListConnectionsRequest(proto.Message):
             Page token.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListConnectionsResponse(proto.Message):
@@ -102,7 +95,7 @@ class ListConnectionsResponse(proto.Message):
     Attributes:
         next_page_token (str):
             Next page token.
-        connections (Sequence[~.gcbc_connection.Connection]):
+        connections (Sequence[google.cloud.bigquery_connection_v1.types.Connection]):
             List of connections.
     """
 
@@ -110,8 +103,7 @@ class ListConnectionsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    next_page_token = proto.Field(proto.STRING, number=1)
-
+    next_page_token = proto.Field(proto.STRING, number=1,)
     connections = proto.RepeatedField(proto.MESSAGE, number=2, message="Connection",)
 
 
@@ -123,31 +115,30 @@ class UpdateConnectionRequest(proto.Message):
         name (str):
             Required. Name of the connection to update, for example:
             ``projects/{project_id}/locations/{location_id}/connections/{connection_id}``
-        connection (~.gcbc_connection.Connection):
+        connection (google.cloud.bigquery_connection_v1.types.Connection):
             Required. Connection containing the updated
             fields.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. Update mask for the connection
             fields to be updated.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     connection = proto.Field(proto.MESSAGE, number=2, message="Connection",)
-
-    update_mask = proto.Field(proto.MESSAGE, number=3, message=field_mask.FieldMask,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+    )
 
 
 class DeleteConnectionRequest(proto.Message):
     r"""The request for [ConnectionService.DeleteConnectionRequest][].
-
     Attributes:
         name (str):
             Required. Name of the deleted connection, for example:
             ``projects/{project_id}/locations/{location_id}/connections/{connection_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class Connection(proto.Message):
@@ -163,9 +154,9 @@ class Connection(proto.Message):
             connection.
         description (str):
             User provided description.
-        cloud_sql (~.gcbc_connection.CloudSqlProperties):
+        cloud_sql (google.cloud.bigquery_connection_v1.types.CloudSqlProperties):
             Cloud SQL properties.
-        aws (~.gcbc_connection.AwsProperties):
+        aws (google.cloud.bigquery_connection_v1.types.AwsProperties):
             Amazon Web Services (AWS) properties.
         creation_time (int):
             Output only. The creation timestamp of the
@@ -178,39 +169,31 @@ class Connection(proto.Message):
             configured for this connection.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    friendly_name = proto.Field(proto.STRING, number=2)
-
-    description = proto.Field(proto.STRING, number=3)
-
+    name = proto.Field(proto.STRING, number=1,)
+    friendly_name = proto.Field(proto.STRING, number=2,)
+    description = proto.Field(proto.STRING, number=3,)
     cloud_sql = proto.Field(
         proto.MESSAGE, number=4, oneof="properties", message="CloudSqlProperties",
     )
-
     aws = proto.Field(
         proto.MESSAGE, number=8, oneof="properties", message="AwsProperties",
     )
-
-    creation_time = proto.Field(proto.INT64, number=5)
-
-    last_modified_time = proto.Field(proto.INT64, number=6)
-
-    has_credential = proto.Field(proto.BOOL, number=7)
+    creation_time = proto.Field(proto.INT64, number=5,)
+    last_modified_time = proto.Field(proto.INT64, number=6,)
+    has_credential = proto.Field(proto.BOOL, number=7,)
 
 
 class CloudSqlProperties(proto.Message):
     r"""Connection properties specific to the Cloud SQL.
-
     Attributes:
         instance_id (str):
             Cloud SQL instance ID in the form
             ``project:location:instance``.
         database (str):
             Database name.
-        type_ (~.gcbc_connection.CloudSqlProperties.DatabaseType):
+        type_ (google.cloud.bigquery_connection_v1.types.CloudSqlProperties.DatabaseType):
             Type of the Cloud SQL database.
-        credential (~.gcbc_connection.CloudSqlCredential):
+        credential (google.cloud.bigquery_connection_v1.types.CloudSqlCredential):
             Input only. Cloud SQL credential.
     """
 
@@ -220,18 +203,14 @@ class CloudSqlProperties(proto.Message):
         POSTGRES = 1
         MYSQL = 2
 
-    instance_id = proto.Field(proto.STRING, number=1)
-
-    database = proto.Field(proto.STRING, number=2)
-
+    instance_id = proto.Field(proto.STRING, number=1,)
+    database = proto.Field(proto.STRING, number=2,)
     type_ = proto.Field(proto.ENUM, number=3, enum=DatabaseType,)
-
     credential = proto.Field(proto.MESSAGE, number=4, message="CloudSqlCredential",)
 
 
 class CloudSqlCredential(proto.Message):
     r"""Credential info for the Cloud SQL.
-
     Attributes:
         username (str):
             The username for the credential.
@@ -239,16 +218,14 @@ class CloudSqlCredential(proto.Message):
             The password for the credential.
     """
 
-    username = proto.Field(proto.STRING, number=1)
-
-    password = proto.Field(proto.STRING, number=2)
+    username = proto.Field(proto.STRING, number=1,)
+    password = proto.Field(proto.STRING, number=2,)
 
 
 class AwsProperties(proto.Message):
     r"""Connection properties specific to Amazon Web Services (AWS).
-
     Attributes:
-        cross_account_role (~.gcbc_connection.AwsCrossAccountRole):
+        cross_account_role (google.cloud.bigquery_connection_v1.types.AwsCrossAccountRole):
             Authentication using Google owned AWS IAM
             user's access key to assume into customer's AWS
             IAM Role.
@@ -281,11 +258,9 @@ class AwsCrossAccountRole(proto.Message):
             https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html
     """
 
-    iam_role_id = proto.Field(proto.STRING, number=1)
-
-    iam_user_id = proto.Field(proto.STRING, number=2)
-
-    external_id = proto.Field(proto.STRING, number=3)
+    iam_role_id = proto.Field(proto.STRING, number=1,)
+    iam_user_id = proto.Field(proto.STRING, number=2,)
+    external_id = proto.Field(proto.STRING, number=3,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
